@@ -7,8 +7,9 @@ if(os.name == 'nt'):
     import win32con
 
 class Server:
-    def __init__(self):
+    def __init__(self, server_port):
         self.server_foldername = 'pages/.server'
+        self.port = server_port
 
     def RemoveDir(self, dir_):
         dir_ = dir_.replace('\\', '/')
@@ -23,7 +24,7 @@ class Server:
 
     def CheckSystem(self):
         a_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        local_connection = ('127.0.0.1', 8891)
+        local_connection = ('127.0.0.1', self.port)
         CHECK_PORT = a_socket.connect_ex(local_connection)
         a_socket.close()
         if(CHECK_PORT != 0):
@@ -34,7 +35,7 @@ class Server:
             if(os.name == 'nt'):
                 win32api.SetFileAttributes(self.server_foldername, win32con.FILE_ATTRIBUTE_HIDDEN)
         else:
-            print('Server starting error on port 8891, Is the yaplee server started by another file?')
+            print('Server starting error on port '+str(self.port)+', Is the yaplee server started by another file?')
             sys.exit(0)
 
     def Stop(self):
